# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.age_range_type_pb2 import (
    AgeRangeTypeEnum as google___ads___googleads___v2___enums___age_range_type_pb2___AgeRangeTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.app_payment_model_type_pb2 import (
    AppPaymentModelTypeEnum as google___ads___googleads___v2___enums___app_payment_model_type_pb2___AppPaymentModelTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.content_label_type_pb2 import (
    ContentLabelTypeEnum as google___ads___googleads___v2___enums___content_label_type_pb2___ContentLabelTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.day_of_week_pb2 import (
    DayOfWeekEnum as google___ads___googleads___v2___enums___day_of_week_pb2___DayOfWeekEnum,
)

from google.ads.google_ads.v2.proto.enums.device_pb2 import (
    DeviceEnum as google___ads___googleads___v2___enums___device_pb2___DeviceEnum,
)

from google.ads.google_ads.v2.proto.enums.gender_type_pb2 import (
    GenderTypeEnum as google___ads___googleads___v2___enums___gender_type_pb2___GenderTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.hotel_date_selection_type_pb2 import (
    HotelDateSelectionTypeEnum as google___ads___googleads___v2___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.income_range_type_pb2 import (
    IncomeRangeTypeEnum as google___ads___googleads___v2___enums___income_range_type_pb2___IncomeRangeTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.interaction_type_pb2 import (
    InteractionTypeEnum as google___ads___googleads___v2___enums___interaction_type_pb2___InteractionTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.keyword_match_type_pb2 import (
    KeywordMatchTypeEnum as google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.listing_custom_attribute_index_pb2 import (
    ListingCustomAttributeIndexEnum as google___ads___googleads___v2___enums___listing_custom_attribute_index_pb2___ListingCustomAttributeIndexEnum,
)

from google.ads.google_ads.v2.proto.enums.listing_group_type_pb2 import (
    ListingGroupTypeEnum as google___ads___googleads___v2___enums___listing_group_type_pb2___ListingGroupTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.location_group_radius_units_pb2 import (
    LocationGroupRadiusUnitsEnum as google___ads___googleads___v2___enums___location_group_radius_units_pb2___LocationGroupRadiusUnitsEnum,
)

from google.ads.google_ads.v2.proto.enums.minute_of_hour_pb2 import (
    MinuteOfHourEnum as google___ads___googleads___v2___enums___minute_of_hour_pb2___MinuteOfHourEnum,
)

from google.ads.google_ads.v2.proto.enums.parental_status_type_pb2 import (
    ParentalStatusTypeEnum as google___ads___googleads___v2___enums___parental_status_type_pb2___ParentalStatusTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.preferred_content_type_pb2 import (
    PreferredContentTypeEnum as google___ads___googleads___v2___enums___preferred_content_type_pb2___PreferredContentTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.product_bidding_category_level_pb2 import (
    ProductBiddingCategoryLevelEnum as google___ads___googleads___v2___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum,
)

from google.ads.google_ads.v2.proto.enums.product_channel_exclusivity_pb2 import (
    ProductChannelExclusivityEnum as google___ads___googleads___v2___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum,
)

from google.ads.google_ads.v2.proto.enums.product_channel_pb2 import (
    ProductChannelEnum as google___ads___googleads___v2___enums___product_channel_pb2___ProductChannelEnum,
)

from google.ads.google_ads.v2.proto.enums.product_condition_pb2 import (
    ProductConditionEnum as google___ads___googleads___v2___enums___product_condition_pb2___ProductConditionEnum,
)

from google.ads.google_ads.v2.proto.enums.product_type_level_pb2 import (
    ProductTypeLevelEnum as google___ads___googleads___v2___enums___product_type_level_pb2___ProductTypeLevelEnum,
)

from google.ads.google_ads.v2.proto.enums.proximity_radius_units_pb2 import (
    ProximityRadiusUnitsEnum as google___ads___googleads___v2___enums___proximity_radius_units_pb2___ProximityRadiusUnitsEnum,
)

from google.ads.google_ads.v2.proto.enums.webpage_condition_operand_pb2 import (
    WebpageConditionOperandEnum as google___ads___googleads___v2___enums___webpage_condition_operand_pb2___WebpageConditionOperandEnum,
)

from google.ads.google_ads.v2.proto.enums.webpage_condition_operator_pb2 import (
    WebpageConditionOperatorEnum as google___ads___googleads___v2___enums___webpage_condition_operator_pb2___WebpageConditionOperatorEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    Int32Value as google___protobuf___wrappers_pb2___Int32Value,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class KeywordInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    match_type = ... # type: google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchType

    @property
    def text(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        text : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        match_type : typing___Optional[google___ads___googleads___v2___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"match_type",u"text"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"text",b"text"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"match_type",b"match_type",u"text",b"text"]) -> None: ...

class PlacementInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PlacementInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"url"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"url",b"url"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"url",b"url"]) -> None: ...

class MobileAppCategoryInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def mobile_app_category_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        mobile_app_category_constant : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MobileAppCategoryInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"mobile_app_category_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"mobile_app_category_constant"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"mobile_app_category_constant",b"mobile_app_category_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"mobile_app_category_constant",b"mobile_app_category_constant"]) -> None: ...

class MobileApplicationInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def app_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        app_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MobileApplicationInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"app_id",u"name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"app_id",u"name"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"app_id",b"app_id",u"name",b"name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"app_id",b"app_id",u"name",b"name"]) -> None: ...

class LocationInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def geo_target_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        geo_target_constant : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> LocationInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"geo_target_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"geo_target_constant"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"geo_target_constant",b"geo_target_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"geo_target_constant",b"geo_target_constant"]) -> None: ...

class DeviceInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___device_pb2___DeviceEnum.Device

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___device_pb2___DeviceEnum.Device] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> DeviceInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"type"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"type",b"type"]) -> None: ...

class PreferredContentInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___preferred_content_type_pb2___PreferredContentTypeEnum.PreferredContentType

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___preferred_content_type_pb2___PreferredContentTypeEnum.PreferredContentType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> PreferredContentInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"type"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"type",b"type"]) -> None: ...

class ListingGroupInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___listing_group_type_pb2___ListingGroupTypeEnum.ListingGroupType

    @property
    def case_value(self) -> ListingDimensionInfo: ...

    @property
    def parent_ad_group_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___listing_group_type_pb2___ListingGroupTypeEnum.ListingGroupType] = None,
        case_value : typing___Optional[ListingDimensionInfo] = None,
        parent_ad_group_criterion : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListingGroupInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"case_value",u"parent_ad_group_criterion"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"case_value",u"parent_ad_group_criterion",u"type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"case_value",b"case_value",u"parent_ad_group_criterion",b"parent_ad_group_criterion"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"case_value",b"case_value",u"parent_ad_group_criterion",b"parent_ad_group_criterion",u"type",b"type"]) -> None: ...

class ListingScopeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def dimensions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ListingDimensionInfo]: ...

    def __init__(self,
        *,
        dimensions : typing___Optional[typing___Iterable[ListingDimensionInfo]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListingScopeInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"dimensions"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"dimensions",b"dimensions"]) -> None: ...

class ListingDimensionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def listing_brand(self) -> ListingBrandInfo: ...

    @property
    def hotel_id(self) -> HotelIdInfo: ...

    @property
    def hotel_class(self) -> HotelClassInfo: ...

    @property
    def hotel_country_region(self) -> HotelCountryRegionInfo: ...

    @property
    def hotel_state(self) -> HotelStateInfo: ...

    @property
    def hotel_city(self) -> HotelCityInfo: ...

    @property
    def listing_custom_attribute(self) -> ListingCustomAttributeInfo: ...

    @property
    def product_bidding_category(self) -> ProductBiddingCategoryInfo: ...

    @property
    def product_channel(self) -> ProductChannelInfo: ...

    @property
    def product_channel_exclusivity(self) -> ProductChannelExclusivityInfo: ...

    @property
    def product_condition(self) -> ProductConditionInfo: ...

    @property
    def product_item_id(self) -> ProductItemIdInfo: ...

    @property
    def product_type(self) -> ProductTypeInfo: ...

    @property
    def unknown_listing_dimension(self) -> UnknownListingDimensionInfo: ...

    def __init__(self,
        *,
        listing_brand : typing___Optional[ListingBrandInfo] = None,
        hotel_id : typing___Optional[HotelIdInfo] = None,
        hotel_class : typing___Optional[HotelClassInfo] = None,
        hotel_country_region : typing___Optional[HotelCountryRegionInfo] = None,
        hotel_state : typing___Optional[HotelStateInfo] = None,
        hotel_city : typing___Optional[HotelCityInfo] = None,
        listing_custom_attribute : typing___Optional[ListingCustomAttributeInfo] = None,
        product_bidding_category : typing___Optional[ProductBiddingCategoryInfo] = None,
        product_channel : typing___Optional[ProductChannelInfo] = None,
        product_channel_exclusivity : typing___Optional[ProductChannelExclusivityInfo] = None,
        product_condition : typing___Optional[ProductConditionInfo] = None,
        product_item_id : typing___Optional[ProductItemIdInfo] = None,
        product_type : typing___Optional[ProductTypeInfo] = None,
        unknown_listing_dimension : typing___Optional[UnknownListingDimensionInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListingDimensionInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"dimension",u"hotel_city",u"hotel_class",u"hotel_country_region",u"hotel_id",u"hotel_state",u"listing_brand",u"listing_custom_attribute",u"product_bidding_category",u"product_channel",u"product_channel_exclusivity",u"product_condition",u"product_item_id",u"product_type",u"unknown_listing_dimension"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"dimension",u"hotel_city",u"hotel_class",u"hotel_country_region",u"hotel_id",u"hotel_state",u"listing_brand",u"listing_custom_attribute",u"product_bidding_category",u"product_channel",u"product_channel_exclusivity",u"product_condition",u"product_item_id",u"product_type",u"unknown_listing_dimension"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"dimension",b"dimension",u"hotel_city",b"hotel_city",u"hotel_class",b"hotel_class",u"hotel_country_region",b"hotel_country_region",u"hotel_id",b"hotel_id",u"hotel_state",b"hotel_state",u"listing_brand",b"listing_brand",u"listing_custom_attribute",b"listing_custom_attribute",u"product_bidding_category",b"product_bidding_category",u"product_channel",b"product_channel",u"product_channel_exclusivity",b"product_channel_exclusivity",u"product_condition",b"product_condition",u"product_item_id",b"product_item_id",u"product_type",b"product_type",u"unknown_listing_dimension",b"unknown_listing_dimension"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"dimension",b"dimension",u"hotel_city",b"hotel_city",u"hotel_class",b"hotel_class",u"hotel_country_region",b"hotel_country_region",u"hotel_id",b"hotel_id",u"hotel_state",b"hotel_state",u"listing_brand",b"listing_brand",u"listing_custom_attribute",b"listing_custom_attribute",u"product_bidding_category",b"product_bidding_category",u"product_channel",b"product_channel",u"product_channel_exclusivity",b"product_channel_exclusivity",u"product_condition",b"product_condition",u"product_item_id",b"product_item_id",u"product_type",b"product_type",u"unknown_listing_dimension",b"unknown_listing_dimension"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"dimension",b"dimension"]) -> typing_extensions___Literal["listing_brand","hotel_id","hotel_class","hotel_country_region","hotel_state","hotel_city","listing_custom_attribute","product_bidding_category","product_channel","product_channel_exclusivity","product_condition","product_item_id","product_type","unknown_listing_dimension"]: ...

class ListingBrandInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        value : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListingBrandInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...

class HotelIdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        value : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> HotelIdInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...

class HotelClassInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def value(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        value : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> HotelClassInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...

class HotelCountryRegionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def country_region_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        country_region_criterion : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> HotelCountryRegionInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"country_region_criterion"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"country_region_criterion"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"country_region_criterion",b"country_region_criterion"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"country_region_criterion",b"country_region_criterion"]) -> None: ...

class HotelStateInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def state_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        state_criterion : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> HotelStateInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"state_criterion"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"state_criterion"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"state_criterion",b"state_criterion"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"state_criterion",b"state_criterion"]) -> None: ...

class HotelCityInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def city_criterion(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        city_criterion : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> HotelCityInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"city_criterion"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"city_criterion"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"city_criterion",b"city_criterion"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"city_criterion",b"city_criterion"]) -> None: ...

class ListingCustomAttributeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    index = ... # type: google___ads___googleads___v2___enums___listing_custom_attribute_index_pb2___ListingCustomAttributeIndexEnum.ListingCustomAttributeIndex

    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        value : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        index : typing___Optional[google___ads___googleads___v2___enums___listing_custom_attribute_index_pb2___ListingCustomAttributeIndexEnum.ListingCustomAttributeIndex] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ListingCustomAttributeInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"index",u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"index",b"index",u"value",b"value"]) -> None: ...

class ProductBiddingCategoryInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    level = ... # type: google___ads___googleads___v2___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        country_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        level : typing___Optional[google___ads___googleads___v2___enums___product_bidding_category_level_pb2___ProductBiddingCategoryLevelEnum.ProductBiddingCategoryLevel] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ProductBiddingCategoryInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"country_code",u"id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"country_code",u"id",u"level"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"country_code",b"country_code",u"id",b"id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"country_code",b"country_code",u"id",b"id",u"level",b"level"]) -> None: ...

class ProductChannelInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    channel = ... # type: google___ads___googleads___v2___enums___product_channel_pb2___ProductChannelEnum.ProductChannel

    def __init__(self,
        *,
        channel : typing___Optional[google___ads___googleads___v2___enums___product_channel_pb2___ProductChannelEnum.ProductChannel] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ProductChannelInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"channel"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"channel",b"channel"]) -> None: ...

class ProductChannelExclusivityInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    channel_exclusivity = ... # type: google___ads___googleads___v2___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum.ProductChannelExclusivity

    def __init__(self,
        *,
        channel_exclusivity : typing___Optional[google___ads___googleads___v2___enums___product_channel_exclusivity_pb2___ProductChannelExclusivityEnum.ProductChannelExclusivity] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ProductChannelExclusivityInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"channel_exclusivity"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"channel_exclusivity",b"channel_exclusivity"]) -> None: ...

class ProductConditionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    condition = ... # type: google___ads___googleads___v2___enums___product_condition_pb2___ProductConditionEnum.ProductCondition

    def __init__(self,
        *,
        condition : typing___Optional[google___ads___googleads___v2___enums___product_condition_pb2___ProductConditionEnum.ProductCondition] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ProductConditionInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"condition"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"condition",b"condition"]) -> None: ...

class ProductItemIdInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        value : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ProductItemIdInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> None: ...

class ProductTypeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    level = ... # type: google___ads___googleads___v2___enums___product_type_level_pb2___ProductTypeLevelEnum.ProductTypeLevel

    @property
    def value(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        value : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        level : typing___Optional[google___ads___googleads___v2___enums___product_type_level_pb2___ProductTypeLevelEnum.ProductTypeLevel] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ProductTypeInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"level",u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"level",b"level",u"value",b"value"]) -> None: ...

class UnknownListingDimensionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UnknownListingDimensionInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...

class HotelDateSelectionTypeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum.HotelDateSelectionType

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___hotel_date_selection_type_pb2___HotelDateSelectionTypeEnum.HotelDateSelectionType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> HotelDateSelectionTypeInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"type"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"type",b"type"]) -> None: ...

class HotelAdvanceBookingWindowInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def min_days(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def max_days(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        min_days : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        max_days : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> HotelAdvanceBookingWindowInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"max_days",u"min_days"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"max_days",u"min_days"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"max_days",b"max_days",u"min_days",b"min_days"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"max_days",b"max_days",u"min_days",b"min_days"]) -> None: ...

class HotelLengthOfStayInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def min_nights(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def max_nights(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        min_nights : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        max_nights : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> HotelLengthOfStayInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"max_nights",u"min_nights"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"max_nights",u"min_nights"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"max_nights",b"max_nights",u"min_nights",b"min_nights"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"max_nights",b"max_nights",u"min_nights",b"min_nights"]) -> None: ...

class HotelCheckInDayInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    day_of_week = ... # type: google___ads___googleads___v2___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeek

    def __init__(self,
        *,
        day_of_week : typing___Optional[google___ads___googleads___v2___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeek] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> HotelCheckInDayInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"day_of_week"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"day_of_week",b"day_of_week"]) -> None: ...

class InteractionTypeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___interaction_type_pb2___InteractionTypeEnum.InteractionType

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___interaction_type_pb2___InteractionTypeEnum.InteractionType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> InteractionTypeInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"type"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"type",b"type"]) -> None: ...

class AdScheduleInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    start_minute = ... # type: google___ads___googleads___v2___enums___minute_of_hour_pb2___MinuteOfHourEnum.MinuteOfHour
    end_minute = ... # type: google___ads___googleads___v2___enums___minute_of_hour_pb2___MinuteOfHourEnum.MinuteOfHour
    day_of_week = ... # type: google___ads___googleads___v2___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeek

    @property
    def start_hour(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    @property
    def end_hour(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    def __init__(self,
        *,
        start_minute : typing___Optional[google___ads___googleads___v2___enums___minute_of_hour_pb2___MinuteOfHourEnum.MinuteOfHour] = None,
        end_minute : typing___Optional[google___ads___googleads___v2___enums___minute_of_hour_pb2___MinuteOfHourEnum.MinuteOfHour] = None,
        start_hour : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        end_hour : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        day_of_week : typing___Optional[google___ads___googleads___v2___enums___day_of_week_pb2___DayOfWeekEnum.DayOfWeek] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AdScheduleInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"end_hour",u"start_hour"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"day_of_week",u"end_hour",u"end_minute",u"start_hour",u"start_minute"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"end_hour",b"end_hour",u"start_hour",b"start_hour"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"day_of_week",b"day_of_week",u"end_hour",b"end_hour",u"end_minute",b"end_minute",u"start_hour",b"start_hour",u"start_minute",b"start_minute"]) -> None: ...

class AgeRangeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___age_range_type_pb2___AgeRangeTypeEnum.AgeRangeType

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___age_range_type_pb2___AgeRangeTypeEnum.AgeRangeType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AgeRangeInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"type"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"type",b"type"]) -> None: ...

class GenderInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___gender_type_pb2___GenderTypeEnum.GenderType

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___gender_type_pb2___GenderTypeEnum.GenderType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GenderInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"type"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"type",b"type"]) -> None: ...

class IncomeRangeInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___income_range_type_pb2___IncomeRangeTypeEnum.IncomeRangeType

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___income_range_type_pb2___IncomeRangeTypeEnum.IncomeRangeType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> IncomeRangeInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"type"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"type",b"type"]) -> None: ...

class ParentalStatusInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___parental_status_type_pb2___ParentalStatusTypeEnum.ParentalStatusType

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___parental_status_type_pb2___ParentalStatusTypeEnum.ParentalStatusType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ParentalStatusInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"type"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"type",b"type"]) -> None: ...

class YouTubeVideoInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def video_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        video_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> YouTubeVideoInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"video_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"video_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"video_id",b"video_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"video_id",b"video_id"]) -> None: ...

class YouTubeChannelInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def channel_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        channel_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> YouTubeChannelInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"channel_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"channel_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"channel_id",b"channel_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"channel_id",b"channel_id"]) -> None: ...

class UserListInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def user_list(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        user_list : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserListInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"user_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"user_list"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"user_list",b"user_list"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"user_list",b"user_list"]) -> None: ...

class ProximityInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    radius_units = ... # type: google___ads___googleads___v2___enums___proximity_radius_units_pb2___ProximityRadiusUnitsEnum.ProximityRadiusUnits

    @property
    def geo_point(self) -> GeoPointInfo: ...

    @property
    def radius(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def address(self) -> AddressInfo: ...

    def __init__(self,
        *,
        geo_point : typing___Optional[GeoPointInfo] = None,
        radius : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        radius_units : typing___Optional[google___ads___googleads___v2___enums___proximity_radius_units_pb2___ProximityRadiusUnitsEnum.ProximityRadiusUnits] = None,
        address : typing___Optional[AddressInfo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ProximityInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"address",u"geo_point",u"radius"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"address",u"geo_point",u"radius",u"radius_units"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"address",b"address",u"geo_point",b"geo_point",u"radius",b"radius"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"address",b"address",u"geo_point",b"geo_point",u"radius",b"radius",u"radius_units",b"radius_units"]) -> None: ...

class GeoPointInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def longitude_in_micro_degrees(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    @property
    def latitude_in_micro_degrees(self) -> google___protobuf___wrappers_pb2___Int32Value: ...

    def __init__(self,
        *,
        longitude_in_micro_degrees : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        latitude_in_micro_degrees : typing___Optional[google___protobuf___wrappers_pb2___Int32Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GeoPointInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"latitude_in_micro_degrees",u"longitude_in_micro_degrees"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"latitude_in_micro_degrees",u"longitude_in_micro_degrees"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"latitude_in_micro_degrees",b"latitude_in_micro_degrees",u"longitude_in_micro_degrees",b"longitude_in_micro_degrees"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"latitude_in_micro_degrees",b"latitude_in_micro_degrees",u"longitude_in_micro_degrees",b"longitude_in_micro_degrees"]) -> None: ...

class AddressInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def postal_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def province_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def country_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def province_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def street_address(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def street_address2(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def city_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        postal_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        province_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        country_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        province_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        street_address : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        street_address2 : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        city_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AddressInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"city_name",u"country_code",u"postal_code",u"province_code",u"province_name",u"street_address",u"street_address2"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"city_name",u"country_code",u"postal_code",u"province_code",u"province_name",u"street_address",u"street_address2"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"city_name",b"city_name",u"country_code",b"country_code",u"postal_code",b"postal_code",u"province_code",b"province_code",u"province_name",b"province_name",u"street_address",b"street_address",u"street_address2",b"street_address2"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"city_name",b"city_name",u"country_code",b"country_code",u"postal_code",b"postal_code",u"province_code",b"province_code",u"province_name",b"province_name",u"street_address",b"street_address",u"street_address2",b"street_address2"]) -> None: ...

class TopicInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def topic_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def path(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    def __init__(self,
        *,
        topic_constant : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        path : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> TopicInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"topic_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"path",u"topic_constant"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"topic_constant",b"topic_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"path",b"path",u"topic_constant",b"topic_constant"]) -> None: ...

class LanguageInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def language_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        language_constant : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> LanguageInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"language_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"language_constant"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"language_constant",b"language_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"language_constant",b"language_constant"]) -> None: ...

class IpBlockInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def ip_address(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        ip_address : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> IpBlockInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ip_address"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ip_address"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ip_address",b"ip_address"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ip_address",b"ip_address"]) -> None: ...

class ContentLabelInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___content_label_type_pb2___ContentLabelTypeEnum.ContentLabelType

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___content_label_type_pb2___ContentLabelTypeEnum.ContentLabelType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ContentLabelInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"type"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"type",b"type"]) -> None: ...

class CarrierInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def carrier_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        carrier_constant : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CarrierInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"carrier_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"carrier_constant"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"carrier_constant",b"carrier_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"carrier_constant",b"carrier_constant"]) -> None: ...

class UserInterestInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def user_interest_category(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        user_interest_category : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UserInterestInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"user_interest_category"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"user_interest_category"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"user_interest_category",b"user_interest_category"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"user_interest_category",b"user_interest_category"]) -> None: ...

class WebpageInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def criterion_name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conditions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[WebpageConditionInfo]: ...

    def __init__(self,
        *,
        criterion_name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conditions : typing___Optional[typing___Iterable[WebpageConditionInfo]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> WebpageInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"criterion_name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conditions",u"criterion_name"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"criterion_name",b"criterion_name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conditions",b"conditions",u"criterion_name",b"criterion_name"]) -> None: ...

class WebpageConditionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    operand = ... # type: google___ads___googleads___v2___enums___webpage_condition_operand_pb2___WebpageConditionOperandEnum.WebpageConditionOperand
    operator = ... # type: google___ads___googleads___v2___enums___webpage_condition_operator_pb2___WebpageConditionOperatorEnum.WebpageConditionOperator

    @property
    def argument(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        operand : typing___Optional[google___ads___googleads___v2___enums___webpage_condition_operand_pb2___WebpageConditionOperandEnum.WebpageConditionOperand] = None,
        operator : typing___Optional[google___ads___googleads___v2___enums___webpage_condition_operator_pb2___WebpageConditionOperatorEnum.WebpageConditionOperator] = None,
        argument : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> WebpageConditionInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"argument"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"argument",u"operand",u"operator"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"argument",b"argument"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"argument",b"argument",u"operand",b"operand",u"operator",b"operator"]) -> None: ...

class OperatingSystemVersionInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def operating_system_version_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        operating_system_version_constant : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> OperatingSystemVersionInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"operating_system_version_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"operating_system_version_constant"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"operating_system_version_constant",b"operating_system_version_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"operating_system_version_constant",b"operating_system_version_constant"]) -> None: ...

class AppPaymentModelInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v2___enums___app_payment_model_type_pb2___AppPaymentModelTypeEnum.AppPaymentModelType

    def __init__(self,
        *,
        type : typing___Optional[google___ads___googleads___v2___enums___app_payment_model_type_pb2___AppPaymentModelTypeEnum.AppPaymentModelType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AppPaymentModelInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"type"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"type",b"type"]) -> None: ...

class MobileDeviceInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def mobile_device_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        mobile_device_constant : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MobileDeviceInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"mobile_device_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"mobile_device_constant"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"mobile_device_constant",b"mobile_device_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"mobile_device_constant",b"mobile_device_constant"]) -> None: ...

class CustomAffinityInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def custom_affinity(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        custom_affinity : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CustomAffinityInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"custom_affinity"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"custom_affinity"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"custom_affinity",b"custom_affinity"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"custom_affinity",b"custom_affinity"]) -> None: ...

class CustomIntentInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def custom_intent(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        custom_intent : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CustomIntentInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"custom_intent"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"custom_intent"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"custom_intent",b"custom_intent"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"custom_intent",b"custom_intent"]) -> None: ...

class LocationGroupInfo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    radius_units = ... # type: google___ads___googleads___v2___enums___location_group_radius_units_pb2___LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnits

    @property
    def feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def geo_target_constants(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def radius(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        feed : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        geo_target_constants : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        radius : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        radius_units : typing___Optional[google___ads___googleads___v2___enums___location_group_radius_units_pb2___LocationGroupRadiusUnitsEnum.LocationGroupRadiusUnits] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> LocationGroupInfo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"feed",u"radius"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"feed",u"geo_target_constants",u"radius",u"radius_units"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"feed",b"feed",u"radius",b"radius"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"feed",b"feed",u"geo_target_constants",b"geo_target_constants",u"radius",b"radius",u"radius_units",b"radius_units"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.resources.google_ads_field_pb2 import (
    GoogleAdsField as google___ads___googleads___v2___resources___google_ads_field_pb2___GoogleAdsField,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GetGoogleAdsFieldRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetGoogleAdsFieldRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class SearchGoogleAdsFieldsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    query = ... # type: typing___Text
    page_token = ... # type: typing___Text
    page_size = ... # type: int

    def __init__(self,
        *,
        query : typing___Optional[typing___Text] = None,
        page_token : typing___Optional[typing___Text] = None,
        page_size : typing___Optional[int] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SearchGoogleAdsFieldsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"page_size",u"page_token",u"query"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"page_size",b"page_size",u"page_token",b"page_token",u"query",b"query"]) -> None: ...

class SearchGoogleAdsFieldsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    next_page_token = ... # type: typing___Text
    total_results_count = ... # type: int

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v2___resources___google_ads_field_pb2___GoogleAdsField]: ...

    def __init__(self,
        *,
        results : typing___Optional[typing___Iterable[google___ads___googleads___v2___resources___google_ads_field_pb2___GoogleAdsField]] = None,
        next_page_token : typing___Optional[typing___Text] = None,
        total_results_count : typing___Optional[int] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> SearchGoogleAdsFieldsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"next_page_token",u"results",u"total_results_count"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"next_page_token",b"next_page_token",u"results",b"results",u"total_results_count",b"total_results_count"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.affiliate_location_feed_relationship_type_pb2 import (
    AffiliateLocationFeedRelationshipTypeEnum as google___ads___googleads___v1___enums___affiliate_location_feed_relationship_type_pb2___AffiliateLocationFeedRelationshipTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.feed_attribute_type_pb2 import (
    FeedAttributeTypeEnum as google___ads___googleads___v1___enums___feed_attribute_type_pb2___FeedAttributeTypeEnum,
)

from google.ads.google_ads.v1.proto.enums.feed_origin_pb2 import (
    FeedOriginEnum as google___ads___googleads___v1___enums___feed_origin_pb2___FeedOriginEnum,
)

from google.ads.google_ads.v1.proto.enums.feed_status_pb2 import (
    FeedStatusEnum as google___ads___googleads___v1___enums___feed_status_pb2___FeedStatusEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BoolValue as google___protobuf___wrappers_pb2___BoolValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    List as typing___List,
    Optional as typing___Optional,
    Text as typing___Text,
    Tuple as typing___Tuple,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class Feed(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class PlacesLocationFeedData(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        class OAuthInfo(google___protobuf___message___Message):
            DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

            @property
            def http_method(self) -> google___protobuf___wrappers_pb2___StringValue: ...

            @property
            def http_request_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

            @property
            def http_authorization_header(self) -> google___protobuf___wrappers_pb2___StringValue: ...

            def __init__(self,
                *,
                http_method : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
                http_request_url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
                http_authorization_header : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
                ) -> None: ...
            @classmethod
            def FromString(cls, s: bytes) -> Feed.PlacesLocationFeedData.OAuthInfo: ...
            def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
            def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
            if sys.version_info >= (3,):
                def HasField(self, field_name: typing_extensions___Literal[u"http_authorization_header",u"http_method",u"http_request_url"]) -> bool: ...
                def ClearField(self, field_name: typing_extensions___Literal[u"http_authorization_header",u"http_method",u"http_request_url"]) -> None: ...
            else:
                def HasField(self, field_name: typing_extensions___Literal[u"http_authorization_header",b"http_authorization_header",u"http_method",b"http_method",u"http_request_url",b"http_request_url"]) -> bool: ...
                def ClearField(self, field_name: typing_extensions___Literal[u"http_authorization_header",b"http_authorization_header",u"http_method",b"http_method",u"http_request_url",b"http_request_url"]) -> None: ...


        @property
        def oauth_info(self) -> Feed.PlacesLocationFeedData.OAuthInfo: ...

        @property
        def email_address(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def business_account_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def business_name_filter(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def category_filters(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

        @property
        def label_filters(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

        def __init__(self,
            *,
            oauth_info : typing___Optional[Feed.PlacesLocationFeedData.OAuthInfo] = None,
            email_address : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            business_account_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            business_name_filter : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            category_filters : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
            label_filters : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> Feed.PlacesLocationFeedData: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"business_account_id",u"business_name_filter",u"email_address",u"oauth_info"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"business_account_id",u"business_name_filter",u"category_filters",u"email_address",u"label_filters",u"oauth_info"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"business_account_id",b"business_account_id",u"business_name_filter",b"business_name_filter",u"email_address",b"email_address",u"oauth_info",b"oauth_info"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"business_account_id",b"business_account_id",u"business_name_filter",b"business_name_filter",u"category_filters",b"category_filters",u"email_address",b"email_address",u"label_filters",b"label_filters",u"oauth_info",b"oauth_info"]) -> None: ...

    class AffiliateLocationFeedData(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        relationship_type = ... # type: google___ads___googleads___v1___enums___affiliate_location_feed_relationship_type_pb2___AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipType

        @property
        def chain_ids(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___Int64Value]: ...

        def __init__(self,
            *,
            chain_ids : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___Int64Value]] = None,
            relationship_type : typing___Optional[google___ads___googleads___v1___enums___affiliate_location_feed_relationship_type_pb2___AffiliateLocationFeedRelationshipTypeEnum.AffiliateLocationFeedRelationshipType] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> Feed.AffiliateLocationFeedData: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"chain_ids",u"relationship_type"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"chain_ids",b"chain_ids",u"relationship_type",b"relationship_type"]) -> None: ...

    resource_name = ... # type: typing___Text
    origin = ... # type: google___ads___googleads___v1___enums___feed_origin_pb2___FeedOriginEnum.FeedOrigin
    status = ... # type: google___ads___googleads___v1___enums___feed_status_pb2___FeedStatusEnum.FeedStatus

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def attributes(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[FeedAttribute]: ...

    @property
    def attribute_operations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[FeedAttributeOperation]: ...

    @property
    def places_location_feed_data(self) -> Feed.PlacesLocationFeedData: ...

    @property
    def affiliate_location_feed_data(self) -> Feed.AffiliateLocationFeedData: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        attributes : typing___Optional[typing___Iterable[FeedAttribute]] = None,
        attribute_operations : typing___Optional[typing___Iterable[FeedAttributeOperation]] = None,
        origin : typing___Optional[google___ads___googleads___v1___enums___feed_origin_pb2___FeedOriginEnum.FeedOrigin] = None,
        status : typing___Optional[google___ads___googleads___v1___enums___feed_status_pb2___FeedStatusEnum.FeedStatus] = None,
        places_location_feed_data : typing___Optional[Feed.PlacesLocationFeedData] = None,
        affiliate_location_feed_data : typing___Optional[Feed.AffiliateLocationFeedData] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> Feed: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"affiliate_location_feed_data",u"id",u"name",u"places_location_feed_data",u"system_feed_generation_data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"affiliate_location_feed_data",u"attribute_operations",u"attributes",u"id",u"name",u"origin",u"places_location_feed_data",u"resource_name",u"status",u"system_feed_generation_data"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"affiliate_location_feed_data",b"affiliate_location_feed_data",u"id",b"id",u"name",b"name",u"places_location_feed_data",b"places_location_feed_data",u"system_feed_generation_data",b"system_feed_generation_data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"affiliate_location_feed_data",b"affiliate_location_feed_data",u"attribute_operations",b"attribute_operations",u"attributes",b"attributes",u"id",b"id",u"name",b"name",u"origin",b"origin",u"places_location_feed_data",b"places_location_feed_data",u"resource_name",b"resource_name",u"status",b"status",u"system_feed_generation_data",b"system_feed_generation_data"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"system_feed_generation_data",b"system_feed_generation_data"]) -> typing_extensions___Literal["places_location_feed_data","affiliate_location_feed_data"]: ...

class FeedAttribute(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    type = ... # type: google___ads___googleads___v1___enums___feed_attribute_type_pb2___FeedAttributeTypeEnum.FeedAttributeType

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def is_part_of_key(self) -> google___protobuf___wrappers_pb2___BoolValue: ...

    def __init__(self,
        *,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        type : typing___Optional[google___ads___googleads___v1___enums___feed_attribute_type_pb2___FeedAttributeTypeEnum.FeedAttributeType] = None,
        is_part_of_key : typing___Optional[google___protobuf___wrappers_pb2___BoolValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedAttribute: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"id",u"is_part_of_key",u"name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"id",u"is_part_of_key",u"name",u"type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"id",b"id",u"is_part_of_key",b"is_part_of_key",u"name",b"name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"id",b"id",u"is_part_of_key",b"is_part_of_key",u"name",b"name",u"type",b"type"]) -> None: ...

class FeedAttributeOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class Operator(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> FeedAttributeOperation.Operator: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[FeedAttributeOperation.Operator]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, FeedAttributeOperation.Operator]]: ...
        UNSPECIFIED = typing___cast(FeedAttributeOperation.Operator, 0)
        UNKNOWN = typing___cast(FeedAttributeOperation.Operator, 1)
        ADD = typing___cast(FeedAttributeOperation.Operator, 2)
    UNSPECIFIED = typing___cast(FeedAttributeOperation.Operator, 0)
    UNKNOWN = typing___cast(FeedAttributeOperation.Operator, 1)
    ADD = typing___cast(FeedAttributeOperation.Operator, 2)

    operator = ... # type: FeedAttributeOperation.Operator

    @property
    def value(self) -> FeedAttribute: ...

    def __init__(self,
        *,
        operator : typing___Optional[FeedAttributeOperation.Operator] = None,
        value : typing___Optional[FeedAttribute] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedAttributeOperation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"operator",u"value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"value",b"value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"operator",b"operator",u"value",b"value"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.ad_customizer_placeholder_field_pb2 import (
    AdCustomizerPlaceholderFieldEnum as google___ads___googleads___v2___enums___ad_customizer_placeholder_field_pb2___AdCustomizerPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.affiliate_location_placeholder_field_pb2 import (
    AffiliateLocationPlaceholderFieldEnum as google___ads___googleads___v2___enums___affiliate_location_placeholder_field_pb2___AffiliateLocationPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.app_placeholder_field_pb2 import (
    AppPlaceholderFieldEnum as google___ads___googleads___v2___enums___app_placeholder_field_pb2___AppPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.call_placeholder_field_pb2 import (
    CallPlaceholderFieldEnum as google___ads___googleads___v2___enums___call_placeholder_field_pb2___CallPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.callout_placeholder_field_pb2 import (
    CalloutPlaceholderFieldEnum as google___ads___googleads___v2___enums___callout_placeholder_field_pb2___CalloutPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.custom_placeholder_field_pb2 import (
    CustomPlaceholderFieldEnum as google___ads___googleads___v2___enums___custom_placeholder_field_pb2___CustomPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.dsa_page_feed_criterion_field_pb2 import (
    DsaPageFeedCriterionFieldEnum as google___ads___googleads___v2___enums___dsa_page_feed_criterion_field_pb2___DsaPageFeedCriterionFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.education_placeholder_field_pb2 import (
    EducationPlaceholderFieldEnum as google___ads___googleads___v2___enums___education_placeholder_field_pb2___EducationPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.feed_mapping_criterion_type_pb2 import (
    FeedMappingCriterionTypeEnum as google___ads___googleads___v2___enums___feed_mapping_criterion_type_pb2___FeedMappingCriterionTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.feed_mapping_status_pb2 import (
    FeedMappingStatusEnum as google___ads___googleads___v2___enums___feed_mapping_status_pb2___FeedMappingStatusEnum,
)

from google.ads.google_ads.v2.proto.enums.flight_placeholder_field_pb2 import (
    FlightPlaceholderFieldEnum as google___ads___googleads___v2___enums___flight_placeholder_field_pb2___FlightPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.hotel_placeholder_field_pb2 import (
    HotelPlaceholderFieldEnum as google___ads___googleads___v2___enums___hotel_placeholder_field_pb2___HotelPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.job_placeholder_field_pb2 import (
    JobPlaceholderFieldEnum as google___ads___googleads___v2___enums___job_placeholder_field_pb2___JobPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.local_placeholder_field_pb2 import (
    LocalPlaceholderFieldEnum as google___ads___googleads___v2___enums___local_placeholder_field_pb2___LocalPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.location_extension_targeting_criterion_field_pb2 import (
    LocationExtensionTargetingCriterionFieldEnum as google___ads___googleads___v2___enums___location_extension_targeting_criterion_field_pb2___LocationExtensionTargetingCriterionFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.location_placeholder_field_pb2 import (
    LocationPlaceholderFieldEnum as google___ads___googleads___v2___enums___location_placeholder_field_pb2___LocationPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.message_placeholder_field_pb2 import (
    MessagePlaceholderFieldEnum as google___ads___googleads___v2___enums___message_placeholder_field_pb2___MessagePlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.placeholder_type_pb2 import (
    PlaceholderTypeEnum as google___ads___googleads___v2___enums___placeholder_type_pb2___PlaceholderTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.price_placeholder_field_pb2 import (
    PricePlaceholderFieldEnum as google___ads___googleads___v2___enums___price_placeholder_field_pb2___PricePlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.promotion_placeholder_field_pb2 import (
    PromotionPlaceholderFieldEnum as google___ads___googleads___v2___enums___promotion_placeholder_field_pb2___PromotionPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.real_estate_placeholder_field_pb2 import (
    RealEstatePlaceholderFieldEnum as google___ads___googleads___v2___enums___real_estate_placeholder_field_pb2___RealEstatePlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.sitelink_placeholder_field_pb2 import (
    SitelinkPlaceholderFieldEnum as google___ads___googleads___v2___enums___sitelink_placeholder_field_pb2___SitelinkPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.structured_snippet_placeholder_field_pb2 import (
    StructuredSnippetPlaceholderFieldEnum as google___ads___googleads___v2___enums___structured_snippet_placeholder_field_pb2___StructuredSnippetPlaceholderFieldEnum,
)

from google.ads.google_ads.v2.proto.enums.travel_placeholder_field_pb2 import (
    TravelPlaceholderFieldEnum as google___ads___googleads___v2___enums___travel_placeholder_field_pb2___TravelPlaceholderFieldEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class FeedMapping(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    status = ... # type: google___ads___googleads___v2___enums___feed_mapping_status_pb2___FeedMappingStatusEnum.FeedMappingStatus
    placeholder_type = ... # type: google___ads___googleads___v2___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderType
    criterion_type = ... # type: google___ads___googleads___v2___enums___feed_mapping_criterion_type_pb2___FeedMappingCriterionTypeEnum.FeedMappingCriterionType

    @property
    def feed(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def attribute_field_mappings(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[AttributeFieldMapping]: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        feed : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        attribute_field_mappings : typing___Optional[typing___Iterable[AttributeFieldMapping]] = None,
        status : typing___Optional[google___ads___googleads___v2___enums___feed_mapping_status_pb2___FeedMappingStatusEnum.FeedMappingStatus] = None,
        placeholder_type : typing___Optional[google___ads___googleads___v2___enums___placeholder_type_pb2___PlaceholderTypeEnum.PlaceholderType] = None,
        criterion_type : typing___Optional[google___ads___googleads___v2___enums___feed_mapping_criterion_type_pb2___FeedMappingCriterionTypeEnum.FeedMappingCriterionType] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> FeedMapping: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"criterion_type",u"feed",u"placeholder_type",u"target"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"attribute_field_mappings",u"criterion_type",u"feed",u"placeholder_type",u"resource_name",u"status",u"target"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"criterion_type",b"criterion_type",u"feed",b"feed",u"placeholder_type",b"placeholder_type",u"target",b"target"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"attribute_field_mappings",b"attribute_field_mappings",u"criterion_type",b"criterion_type",u"feed",b"feed",u"placeholder_type",b"placeholder_type",u"resource_name",b"resource_name",u"status",b"status",u"target",b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"target",b"target"]) -> typing_extensions___Literal["placeholder_type","criterion_type"]: ...

class AttributeFieldMapping(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    sitelink_field = ... # type: google___ads___googleads___v2___enums___sitelink_placeholder_field_pb2___SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField
    call_field = ... # type: google___ads___googleads___v2___enums___call_placeholder_field_pb2___CallPlaceholderFieldEnum.CallPlaceholderField
    app_field = ... # type: google___ads___googleads___v2___enums___app_placeholder_field_pb2___AppPlaceholderFieldEnum.AppPlaceholderField
    location_field = ... # type: google___ads___googleads___v2___enums___location_placeholder_field_pb2___LocationPlaceholderFieldEnum.LocationPlaceholderField
    affiliate_location_field = ... # type: google___ads___googleads___v2___enums___affiliate_location_placeholder_field_pb2___AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField
    callout_field = ... # type: google___ads___googleads___v2___enums___callout_placeholder_field_pb2___CalloutPlaceholderFieldEnum.CalloutPlaceholderField
    structured_snippet_field = ... # type: google___ads___googleads___v2___enums___structured_snippet_placeholder_field_pb2___StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField
    message_field = ... # type: google___ads___googleads___v2___enums___message_placeholder_field_pb2___MessagePlaceholderFieldEnum.MessagePlaceholderField
    price_field = ... # type: google___ads___googleads___v2___enums___price_placeholder_field_pb2___PricePlaceholderFieldEnum.PricePlaceholderField
    promotion_field = ... # type: google___ads___googleads___v2___enums___promotion_placeholder_field_pb2___PromotionPlaceholderFieldEnum.PromotionPlaceholderField
    ad_customizer_field = ... # type: google___ads___googleads___v2___enums___ad_customizer_placeholder_field_pb2___AdCustomizerPlaceholderFieldEnum.AdCustomizerPlaceholderField
    dsa_page_feed_field = ... # type: google___ads___googleads___v2___enums___dsa_page_feed_criterion_field_pb2___DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField
    location_extension_targeting_field = ... # type: google___ads___googleads___v2___enums___location_extension_targeting_criterion_field_pb2___LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField
    education_field = ... # type: google___ads___googleads___v2___enums___education_placeholder_field_pb2___EducationPlaceholderFieldEnum.EducationPlaceholderField
    flight_field = ... # type: google___ads___googleads___v2___enums___flight_placeholder_field_pb2___FlightPlaceholderFieldEnum.FlightPlaceholderField
    custom_field = ... # type: google___ads___googleads___v2___enums___custom_placeholder_field_pb2___CustomPlaceholderFieldEnum.CustomPlaceholderField
    hotel_field = ... # type: google___ads___googleads___v2___enums___hotel_placeholder_field_pb2___HotelPlaceholderFieldEnum.HotelPlaceholderField
    real_estate_field = ... # type: google___ads___googleads___v2___enums___real_estate_placeholder_field_pb2___RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField
    travel_field = ... # type: google___ads___googleads___v2___enums___travel_placeholder_field_pb2___TravelPlaceholderFieldEnum.TravelPlaceholderField
    local_field = ... # type: google___ads___googleads___v2___enums___local_placeholder_field_pb2___LocalPlaceholderFieldEnum.LocalPlaceholderField
    job_field = ... # type: google___ads___googleads___v2___enums___job_placeholder_field_pb2___JobPlaceholderFieldEnum.JobPlaceholderField

    @property
    def feed_attribute_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def field_id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        feed_attribute_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        field_id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        sitelink_field : typing___Optional[google___ads___googleads___v2___enums___sitelink_placeholder_field_pb2___SitelinkPlaceholderFieldEnum.SitelinkPlaceholderField] = None,
        call_field : typing___Optional[google___ads___googleads___v2___enums___call_placeholder_field_pb2___CallPlaceholderFieldEnum.CallPlaceholderField] = None,
        app_field : typing___Optional[google___ads___googleads___v2___enums___app_placeholder_field_pb2___AppPlaceholderFieldEnum.AppPlaceholderField] = None,
        location_field : typing___Optional[google___ads___googleads___v2___enums___location_placeholder_field_pb2___LocationPlaceholderFieldEnum.LocationPlaceholderField] = None,
        affiliate_location_field : typing___Optional[google___ads___googleads___v2___enums___affiliate_location_placeholder_field_pb2___AffiliateLocationPlaceholderFieldEnum.AffiliateLocationPlaceholderField] = None,
        callout_field : typing___Optional[google___ads___googleads___v2___enums___callout_placeholder_field_pb2___CalloutPlaceholderFieldEnum.CalloutPlaceholderField] = None,
        structured_snippet_field : typing___Optional[google___ads___googleads___v2___enums___structured_snippet_placeholder_field_pb2___StructuredSnippetPlaceholderFieldEnum.StructuredSnippetPlaceholderField] = None,
        message_field : typing___Optional[google___ads___googleads___v2___enums___message_placeholder_field_pb2___MessagePlaceholderFieldEnum.MessagePlaceholderField] = None,
        price_field : typing___Optional[google___ads___googleads___v2___enums___price_placeholder_field_pb2___PricePlaceholderFieldEnum.PricePlaceholderField] = None,
        promotion_field : typing___Optional[google___ads___googleads___v2___enums___promotion_placeholder_field_pb2___PromotionPlaceholderFieldEnum.PromotionPlaceholderField] = None,
        ad_customizer_field : typing___Optional[google___ads___googleads___v2___enums___ad_customizer_placeholder_field_pb2___AdCustomizerPlaceholderFieldEnum.AdCustomizerPlaceholderField] = None,
        dsa_page_feed_field : typing___Optional[google___ads___googleads___v2___enums___dsa_page_feed_criterion_field_pb2___DsaPageFeedCriterionFieldEnum.DsaPageFeedCriterionField] = None,
        location_extension_targeting_field : typing___Optional[google___ads___googleads___v2___enums___location_extension_targeting_criterion_field_pb2___LocationExtensionTargetingCriterionFieldEnum.LocationExtensionTargetingCriterionField] = None,
        education_field : typing___Optional[google___ads___googleads___v2___enums___education_placeholder_field_pb2___EducationPlaceholderFieldEnum.EducationPlaceholderField] = None,
        flight_field : typing___Optional[google___ads___googleads___v2___enums___flight_placeholder_field_pb2___FlightPlaceholderFieldEnum.FlightPlaceholderField] = None,
        custom_field : typing___Optional[google___ads___googleads___v2___enums___custom_placeholder_field_pb2___CustomPlaceholderFieldEnum.CustomPlaceholderField] = None,
        hotel_field : typing___Optional[google___ads___googleads___v2___enums___hotel_placeholder_field_pb2___HotelPlaceholderFieldEnum.HotelPlaceholderField] = None,
        real_estate_field : typing___Optional[google___ads___googleads___v2___enums___real_estate_placeholder_field_pb2___RealEstatePlaceholderFieldEnum.RealEstatePlaceholderField] = None,
        travel_field : typing___Optional[google___ads___googleads___v2___enums___travel_placeholder_field_pb2___TravelPlaceholderFieldEnum.TravelPlaceholderField] = None,
        local_field : typing___Optional[google___ads___googleads___v2___enums___local_placeholder_field_pb2___LocalPlaceholderFieldEnum.LocalPlaceholderField] = None,
        job_field : typing___Optional[google___ads___googleads___v2___enums___job_placeholder_field_pb2___JobPlaceholderFieldEnum.JobPlaceholderField] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> AttributeFieldMapping: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_customizer_field",u"affiliate_location_field",u"app_field",u"call_field",u"callout_field",u"custom_field",u"dsa_page_feed_field",u"education_field",u"feed_attribute_id",u"field",u"field_id",u"flight_field",u"hotel_field",u"job_field",u"local_field",u"location_extension_targeting_field",u"location_field",u"message_field",u"price_field",u"promotion_field",u"real_estate_field",u"sitelink_field",u"structured_snippet_field",u"travel_field"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_customizer_field",u"affiliate_location_field",u"app_field",u"call_field",u"callout_field",u"custom_field",u"dsa_page_feed_field",u"education_field",u"feed_attribute_id",u"field",u"field_id",u"flight_field",u"hotel_field",u"job_field",u"local_field",u"location_extension_targeting_field",u"location_field",u"message_field",u"price_field",u"promotion_field",u"real_estate_field",u"sitelink_field",u"structured_snippet_field",u"travel_field"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_customizer_field",b"ad_customizer_field",u"affiliate_location_field",b"affiliate_location_field",u"app_field",b"app_field",u"call_field",b"call_field",u"callout_field",b"callout_field",u"custom_field",b"custom_field",u"dsa_page_feed_field",b"dsa_page_feed_field",u"education_field",b"education_field",u"feed_attribute_id",b"feed_attribute_id",u"field",b"field",u"field_id",b"field_id",u"flight_field",b"flight_field",u"hotel_field",b"hotel_field",u"job_field",b"job_field",u"local_field",b"local_field",u"location_extension_targeting_field",b"location_extension_targeting_field",u"location_field",b"location_field",u"message_field",b"message_field",u"price_field",b"price_field",u"promotion_field",b"promotion_field",u"real_estate_field",b"real_estate_field",u"sitelink_field",b"sitelink_field",u"structured_snippet_field",b"structured_snippet_field",u"travel_field",b"travel_field"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_customizer_field",b"ad_customizer_field",u"affiliate_location_field",b"affiliate_location_field",u"app_field",b"app_field",u"call_field",b"call_field",u"callout_field",b"callout_field",u"custom_field",b"custom_field",u"dsa_page_feed_field",b"dsa_page_feed_field",u"education_field",b"education_field",u"feed_attribute_id",b"feed_attribute_id",u"field",b"field",u"field_id",b"field_id",u"flight_field",b"flight_field",u"hotel_field",b"hotel_field",u"job_field",b"job_field",u"local_field",b"local_field",u"location_extension_targeting_field",b"location_extension_targeting_field",u"location_field",b"location_field",u"message_field",b"message_field",u"price_field",b"price_field",u"promotion_field",b"promotion_field",u"real_estate_field",b"real_estate_field",u"sitelink_field",b"sitelink_field",u"structured_snippet_field",b"structured_snippet_field",u"travel_field",b"travel_field"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"field",b"field"]) -> typing_extensions___Literal["sitelink_field","call_field","app_field","location_field","affiliate_location_field","callout_field","structured_snippet_field","message_field","price_field","promotion_field","ad_customizer_field","dsa_page_feed_field","location_extension_targeting_field","education_field","flight_field","custom_field","hotel_field","real_estate_field","travel_field","local_field","job_field"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class KeywordPlanErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class KeywordPlanError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> KeywordPlanErrorEnum.KeywordPlanError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[KeywordPlanErrorEnum.KeywordPlanError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, KeywordPlanErrorEnum.KeywordPlanError]]: ...
        UNSPECIFIED = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 0)
        UNKNOWN = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 1)
        BID_MULTIPLIER_OUT_OF_RANGE = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 2)
        BID_TOO_HIGH = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 3)
        BID_TOO_LOW = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 4)
        BID_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 5)
        DAILY_BUDGET_TOO_LOW = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 6)
        DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 7)
        INVALID_VALUE = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 8)
        KEYWORD_PLAN_HAS_NO_KEYWORDS = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 9)
        KEYWORD_PLAN_NOT_ENABLED = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 10)
        KEYWORD_PLAN_NOT_FOUND = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 11)
        MISSING_BID = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 13)
        MISSING_FORECAST_PERIOD = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 14)
        INVALID_FORECAST_DATE_RANGE = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 15)
        INVALID_NAME = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 16)
    UNSPECIFIED = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 0)
    UNKNOWN = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 1)
    BID_MULTIPLIER_OUT_OF_RANGE = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 2)
    BID_TOO_HIGH = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 3)
    BID_TOO_LOW = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 4)
    BID_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 5)
    DAILY_BUDGET_TOO_LOW = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 6)
    DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 7)
    INVALID_VALUE = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 8)
    KEYWORD_PLAN_HAS_NO_KEYWORDS = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 9)
    KEYWORD_PLAN_NOT_ENABLED = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 10)
    KEYWORD_PLAN_NOT_FOUND = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 11)
    MISSING_BID = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 13)
    MISSING_FORECAST_PERIOD = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 14)
    INVALID_FORECAST_DATE_RANGE = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 15)
    INVALID_NAME = typing___cast(KeywordPlanErrorEnum.KeywordPlanError, 16)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



import grpc  # type: ignore
from google.ads.google_ads.v2.services.transports.campaign_experiment_service_grpc_transport import CampaignExperimentServiceGrpcTransport
from google.api_core.operation import Operation  # type: ignore
from google.auth.credentials import Credentials  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from typing import Optional, Dict, Any, List, Sequence, Tuple, Union, Callable, ClassVar, Iterator
from google.ads.google_ads.v2.proto.resources.campaign_experiment_pb2 import CampaignExperiment
from google.ads.google_ads.v2.proto.services.campaign_experiment_service_pb2 import CampaignExperimentOperation, \
    MutateCampaignExperimentsResponse, GraduateCampaignExperimentResponse

from google.rpc.status_pb2 import Status


class CampaignExperimentServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args: Any, **kwargs: Any) -> CampaignExperimentServiceClient: ...
    @classmethod
    def from_service_account_json(cls, filename: str, *args: Any, **kwargs: Any) -> CampaignExperimentServiceClient: ...
    @classmethod
    def campaign_experiment_path(cls, customer: Any, campaign_experiment: Any) -> str: ...
    transport: Union[CampaignExperimentServiceGrpcTransport, Callable[[Credentials, type], CampaignExperimentServiceGrpcTransport]] = ...
    def __init__(self, transport: Optional[Union[CampaignExperimentServiceGrpcTransport, Callable[[Credentials, type], CampaignExperimentServiceGrpcTransport]]] = ..., channel: Optional[grpc.Channel] = ..., credentials: Optional[Credentials] = ..., client_config: Optional[Dict[Any, Any]] = ..., client_info: Optional[ClientInfo] = ...) -> None: ...
    def get_campaign_experiment(self, resource_name: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> CampaignExperiment: ...
    def create_campaign_experiment(self, customer_id: str, campaign_experiment: Union[Dict[Any, Any], CampaignExperiment], validate_only: Optional[bool] = ..., retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> Operation: ...
    def mutate_campaign_experiments(self, customer_id: str, operations: List[Union[Dict[Any, Any], CampaignExperimentOperation]], partial_failure: Optional[bool] = ..., validate_only: Optional[bool] = ..., retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> MutateCampaignExperimentsResponse: ...
    def graduate_campaign_experiment(self, campaign_experiment: str, campaign_budget: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> GraduateCampaignExperimentResponse: ...
    def promote_campaign_experiment(self, campaign_experiment: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> Operation: ...
    def end_campaign_experiment(self, campaign_experiment: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> None: ...
    def list_campaign_experiment_async_errors(self, resource_name: str, page_size: Optional[int] = ..., retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> Iterator[Status]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ManagerLinkErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ManagerLinkError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ManagerLinkErrorEnum.ManagerLinkError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ManagerLinkErrorEnum.ManagerLinkError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ManagerLinkErrorEnum.ManagerLinkError]]: ...
        UNSPECIFIED = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 0)
        UNKNOWN = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 1)
        ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 2)
        TOO_MANY_MANAGERS = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 3)
        TOO_MANY_INVITES = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 4)
        ALREADY_INVITED_BY_THIS_MANAGER = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 5)
        ALREADY_MANAGED_BY_THIS_MANAGER = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 6)
        ALREADY_MANAGED_IN_HIERARCHY = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 7)
        DUPLICATE_CHILD_FOUND = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 8)
        CLIENT_HAS_NO_ADMIN_USER = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 9)
        MAX_DEPTH_EXCEEDED = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 10)
        CYCLE_NOT_ALLOWED = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 11)
        TOO_MANY_ACCOUNTS = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 12)
        TOO_MANY_ACCOUNTS_AT_MANAGER = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 13)
        NON_OWNER_USER_CANNOT_MODIFY_LINK = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 14)
        SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 15)
    UNSPECIFIED = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 0)
    UNKNOWN = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 1)
    ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 2)
    TOO_MANY_MANAGERS = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 3)
    TOO_MANY_INVITES = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 4)
    ALREADY_INVITED_BY_THIS_MANAGER = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 5)
    ALREADY_MANAGED_BY_THIS_MANAGER = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 6)
    ALREADY_MANAGED_IN_HIERARCHY = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 7)
    DUPLICATE_CHILD_FOUND = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 8)
    CLIENT_HAS_NO_ADMIN_USER = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 9)
    MAX_DEPTH_EXCEEDED = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 10)
    CYCLE_NOT_ALLOWED = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 11)
    TOO_MANY_ACCOUNTS = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 12)
    TOO_MANY_ACCOUNTS_AT_MANAGER = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 13)
    NON_OWNER_USER_CANNOT_MODIFY_LINK = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 14)
    SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS = typing___cast(ManagerLinkErrorEnum.ManagerLinkError, 15)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ManagerLinkErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
